# Table functions

API reference for all pre-defined [`CapturedCallable`][vizro.models.types.CapturedCallable] table functions to be used in the
[`AgGrid`][vizro.models.AgGrid] and [`Table`][vizro.models.Table] models. Visit the How-to guide on [tables](../user-guides/table.md)
for more information.

::: vizro.tables
    options:
      show_source: true
